==> istio-model-v1alpha3-6.0.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/WorkloadEntryListFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class WorkloadEntryListFluentImpl<A extends WorkloadEntryListFluent<A>> extends BaseFluent<A> implements WorkloadEntryListFluent<A>{
  public WorkloadEntryListFluentImpl() {
  }
  public WorkloadEntryListFluentImpl(WorkloadEntryList instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
  }
  private String apiVersion;
  private ArrayList<WorkloadEntryBuilder> items = new ArrayList<WorkloadEntryBuilder>();
  private String kind;
  private ListMeta metadata;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public A addToItems(Integer index,WorkloadEntry item) {
    if (this.items == null) {this.items = new ArrayList<WorkloadEntryBuilder>();}
    WorkloadEntryBuilder builder = new WorkloadEntryBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
  }
  public A setToItems(Integer index,WorkloadEntry item) {
    if (this.items == null) {this.items = new ArrayList<WorkloadEntryBuilder>();}
    WorkloadEntryBuilder builder = new WorkloadEntryBuilder(item);
    if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
    if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
     return (A)this;
  }
  public A addToItems(io.fabric8.istio.api.networking.v1alpha3.WorkloadEntry... items) {
    if (this.items == null) {this.items = new ArrayList<WorkloadEntryBuilder>();}
    for (WorkloadEntry item : items) {WorkloadEntryBuilder builder = new WorkloadEntryBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A addAllToItems(Collection<WorkloadEntry> items) {
    if (this.items == null) {this.items = new ArrayList<WorkloadEntryBuilder>();}
    for (WorkloadEntry item : items) {WorkloadEntryBuilder builder = new WorkloadEntryBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A removeFromItems(io.fabric8.istio.api.networking.v1alpha3.WorkloadEntry... items) {
    for (WorkloadEntry item : items) {WorkloadEntryBuilder builder = new WorkloadEntryBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeAllFromItems(Collection<WorkloadEntry> items) {
    for (WorkloadEntry item : items) {WorkloadEntryBuilder builder = new WorkloadEntryBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromItems(Predicate<WorkloadEntryBuilder> predicate) {
    if (items == null) return (A) this;
    final Iterator<WorkloadEntryBuilder> each = items.iterator();
    final List visitables = _visitables.get("items");
    while (each.hasNext()) {
      WorkloadEntryBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<WorkloadEntry> getItems() {
    return items != null ? build(items) : null;
  }
  public List<WorkloadEntry> buildItems() {
    return items != null ? build(items) : null;
  }
  public WorkloadEntry buildItem(Integer index) {
    return this.items.get(index).build();
  }
  public WorkloadEntry buildFirstItem() {
    return this.items.get(0).build();
  }
  public WorkloadEntry buildLastItem() {
    return this.items.get(items.size() - 1).build();
  }
  public WorkloadEntry buildMatchingItem(Predicate<WorkloadEntryBuilder> predicate) {
    for (WorkloadEntryBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingItem(Predicate<WorkloadEntryBuilder> predicate) {
    for (WorkloadEntryBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withItems(List<WorkloadEntry> items) {
    if (this.items != null) { _visitables.get("items").removeAll(this.items);}
    if (items != null) {this.items = new ArrayList(); for (WorkloadEntry item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
  }
  public A withItems(io.fabric8.istio.api.networking.v1alpha3.WorkloadEntry... items) {
    if (this.items != null) {this.items.clear();}
    if (items != null) {for (WorkloadEntry item :items){ this.addToItems(item);}} return (A) this;
  }
  public Boolean hasItems() {
    return items != null && !items.isEmpty();
  }
  public WorkloadEntryListFluent.ItemsNested<A> addNewItem() {
    return new WorkloadEntryListFluentImpl.ItemsNestedImpl();
  }
  public WorkloadEntryListFluent.ItemsNested<A> addNewItemLike(WorkloadEntry item) {
    return new WorkloadEntryListFluentImpl.ItemsNestedImpl(-1, item);
  }
  public WorkloadEntryListFluent.ItemsNested<A> setNewItemLike(Integer index,WorkloadEntry item) {
    return new WorkloadEntryListFluentImpl.ItemsNestedImpl(index, item);
  }
  public WorkloadEntryListFluent.ItemsNested<A> editItem(Integer index) {
    if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
    return setNewItemLike(index, buildItem(index));
  }
  public WorkloadEntryListFluent.ItemsNested<A> editFirstItem() {
    if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
    return setNewItemLike(0, buildItem(0));
  }
  public WorkloadEntryListFluent.ItemsNested<A> editLastItem() {
    int index = items.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
    return setNewItemLike(index, buildItem(index));
  }
  public WorkloadEntryListFluent.ItemsNested<A> editMatchingItem(Predicate<WorkloadEntryBuilder> predicate) {
    int index = -1;
    for (int i=0;i<items.size();i++) { 
    if (predicate.test(items.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
    return setNewItemLike(index, buildItem(index));
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  public ListMeta getMetadata() {
    return this.metadata;
  }
  public A withMetadata(ListMeta metadata) {
    this.metadata=metadata; return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
    return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    WorkloadEntryListFluentImpl that = (WorkloadEntryListFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (items != null ? !items.equals(that.items) :that.items != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (items != null && !items.isEmpty()) { sb.append("items:"); sb.append(items + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata); }
    sb.append("}");
    return sb.toString();
  }
  class ItemsNestedImpl<N> extends WorkloadEntryFluentImpl<WorkloadEntryListFluent.ItemsNested<N>> implements WorkloadEntryListFluent.ItemsNested<N>,Nested<N>{
    ItemsNestedImpl(Integer index,WorkloadEntry item) {
      this.index = index;
      this.builder = new WorkloadEntryBuilder(this, item);
    }
    ItemsNestedImpl() {
      this.index = -1;
      this.builder = new WorkloadEntryBuilder(this);
    }
    WorkloadEntryBuilder builder;
    Integer index;
    public N and() {
      return (N) WorkloadEntryListFluentImpl.this.setToItems(index,builder.build());
    }
    public N endItem() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/WorkloadEntryListFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class WorkloadEntryListFluentImpl<A extends WorkloadEntryListFluent<A>> extends BaseFluent<A> implements WorkloadEntryListFluent<A>{
  public WorkloadEntryListFluentImpl() {
  }
  public WorkloadEntryListFluentImpl(WorkloadEntryList instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
  }
  private String apiVersion;
  private ArrayList<WorkloadEntryBuilder> items = new ArrayList<WorkloadEntryBuilder>();
  private String kind;
  private ListMeta metadata;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public A addToItems(int index,WorkloadEntry item) {
    if (this.items == null) {this.items = new ArrayList<WorkloadEntryBuilder>();}
    WorkloadEntryBuilder builder = new WorkloadEntryBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").add(index, builder); items.add(index, builder);}
    return (A)this;
  }
  public A setToItems(int index,WorkloadEntry item) {
    if (this.items == null) {this.items = new ArrayList<WorkloadEntryBuilder>();}
    WorkloadEntryBuilder builder = new WorkloadEntryBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").set(index, builder); items.set(index, builder);}
    return (A)this;
  }
  public A addToItems(io.fabric8.istio.api.networking.v1alpha3.WorkloadEntry... items) {
    if (this.items == null) {this.items = new ArrayList<WorkloadEntryBuilder>();}
    for (WorkloadEntry item : items) {WorkloadEntryBuilder builder = new WorkloadEntryBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A addAllToItems(Collection<WorkloadEntry> items) {
    if (this.items == null) {this.items = new ArrayList<WorkloadEntryBuilder>();}
    for (WorkloadEntry item : items) {WorkloadEntryBuilder builder = new WorkloadEntryBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A removeFromItems(io.fabric8.istio.api.networking.v1alpha3.WorkloadEntry... items) {
    for (WorkloadEntry item : items) {WorkloadEntryBuilder builder = new WorkloadEntryBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeAllFromItems(Collection<WorkloadEntry> items) {
    for (WorkloadEntry item : items) {WorkloadEntryBuilder builder = new WorkloadEntryBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromItems(Predicate<WorkloadEntryBuilder> predicate) {
    if (items == null) return (A) this;
    final Iterator<WorkloadEntryBuilder> each = items.iterator();
    final List visitables = _visitables.get("items");
    while (each.hasNext()) {
      WorkloadEntryBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<WorkloadEntry> getItems() {
    return items != null ? build(items) : null;
  }
  public List<WorkloadEntry> buildItems() {
    return items != null ? build(items) : null;
  }
  public WorkloadEntry buildItem(int index) {
    return this.items.get(index).build();
  }
  public WorkloadEntry buildFirstItem() {
    return this.items.get(0).build();
  }
  public WorkloadEntry buildLastItem() {
    return this.items.get(items.size() - 1).build();
  }
  public WorkloadEntry buildMatchingItem(Predicate<WorkloadEntryBuilder> predicate) {
    for (WorkloadEntryBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingItem(Predicate<WorkloadEntryBuilder> predicate) {
    for (WorkloadEntryBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withItems(List<WorkloadEntry> items) {
    if (this.items != null) { _visitables.get("items").clear();}
    if (items != null) {this.items = new ArrayList(); for (WorkloadEntry item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
  }
  public A withItems(io.fabric8.istio.api.networking.v1alpha3.WorkloadEntry... items) {
    if (this.items != null) {this.items.clear(); _visitables.remove("items"); }
    if (items != null) {for (WorkloadEntry item :items){ this.addToItems(item);}} return (A) this;
  }
  public Boolean hasItems() {
    return items != null && !items.isEmpty();
  }
  public WorkloadEntryListFluentImpl.ItemsNested<A> addNewItem() {
    return new WorkloadEntryListFluentImpl.ItemsNestedImpl();
  }
  public WorkloadEntryListFluentImpl.ItemsNested<A> addNewItemLike(WorkloadEntry item) {
    return new WorkloadEntryListFluentImpl.ItemsNestedImpl(-1, item);
  }
  public WorkloadEntryListFluentImpl.ItemsNested<A> setNewItemLike(int index,WorkloadEntry item) {
    return new WorkloadEntryListFluentImpl.ItemsNestedImpl(index, item);
  }
  public WorkloadEntryListFluentImpl.ItemsNested<A> editItem(int index) {
    if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
    return setNewItemLike(index, buildItem(index));
  }
  public WorkloadEntryListFluentImpl.ItemsNested<A> editFirstItem() {
    if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
    return setNewItemLike(0, buildItem(0));
  }
  public WorkloadEntryListFluentImpl.ItemsNested<A> editLastItem() {
    int index = items.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
    return setNewItemLike(index, buildItem(index));
  }
  public WorkloadEntryListFluentImpl.ItemsNested<A> editMatchingItem(Predicate<WorkloadEntryBuilder> predicate) {
    int index = -1;
    for (int i=0;i<items.size();i++) { 
    if (predicate.test(items.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
    return setNewItemLike(index, buildItem(index));
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  public ListMeta getMetadata() {
    return this.metadata;
  }
  public A withMetadata(ListMeta metadata) {
    this.metadata=metadata; return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
    return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    WorkloadEntryListFluentImpl that = (WorkloadEntryListFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(items, that.items)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (items != null) { sb.append("items:"); sb.append(items + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata); }
    sb.append("}");
    return sb.toString();
  }
  class ItemsNestedImpl<N> extends WorkloadEntryFluentImpl<WorkloadEntryListFluentImpl.ItemsNested<N>> implements WorkloadEntryListFluentImpl.ItemsNested<N>,Nested<N>{
    ItemsNestedImpl(int index,WorkloadEntry item) {
      this.index = index;
      this.builder = new WorkloadEntryBuilder(this, item);
    }
    ItemsNestedImpl() {
      this.index = -1;
      this.builder = new WorkloadEntryBuilder(this);
    }
    WorkloadEntryBuilder builder;
    int index;
    public N and() {
      return (N) WorkloadEntryListFluentImpl.this.setToItems(index,builder.build());
    }
    public N endItem() {
      return and();
    }
    
  }
  
}
